@@ -1,4 +1,5 @@
 import os, shutil
+from datetime import datetime, date, timedelta
 def writeLogTxt( name='_Log_for_Database_UNDEFINED.txt',data="Error",root_directory_name="rep",dir_name = '_LOG'):
     """Write log in .txt file
 
@@ -31,4 +32,13 @@ def makeDirectrory(dir_name):
                 os.mkdir(i, mode=0o777, dir_fd=None)
     else:     
         if not os.path.isdir(dir_name):
-            os.mkdir(dir_name, mode=0o777, dir_fd=None)
\ No newline at end of file
+            os.mkdir(dir_name, mode=0o777, dir_fd=None)
+def getNameFileOutput():
+    """Return date with the form YYYYMMDD
+
+    Returns:
+        Date: YYYYMMDD
+    """
+    mydate = str(datetime.now()).split('.')[0]
+    d = datetime.strptime(mydate, "%Y-%m-%d  %H:%M:%S")
+    return d.strftime("%Y%m%d")
\ No newline at end of file
